@@ -5,7 +5,7 @@
  * later. See the COPYING file.
  *
  * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @copyright Christoph Wurst 2016
+ * @copyright Christoph Wurst 2017
  */
 
 define(function(require) {
@@ -18,7 +18,7 @@ define(function(require) {
 	var OC = require('OC');
 	var Radio = require('radio');
 	var Attachments = require('models/attachments');
-	var AttachmentsView = require('views/attachments');
+	var AttachmentsView = require('views/attachmentsview');
 	var ComposerTemplate = require('text!templates/composer.html');
 
 	return Marionette.View.extend({
@@ -115,6 +115,7 @@ define(function(require) {
 			 * Attachments sub-view
 			 */
 			this.attachments = new Attachments();
+			this.bindAttachments();
 
 			/**
 			 * Data for replies
@@ -166,6 +167,11 @@ define(function(require) {
 				this.autosized = false;
 			}
 		},
+		bindAttachments: function() {
+			// when the attachment list changed (add, remove, change), we make sure
+			// to update the 'Send' button
+			this.attachments.bind('all', this.onInputChanged.bind(this));
+		},
 		isReply: function() {
 			return this.type === 'reply';
 		},
@@ -174,7 +180,9 @@ define(function(require) {
 			var to = this.$('.to').val();
 			var subject = this.$('.subject').val();
 			var body = this.$('.message-body').val();
-			if (to !== '' || subject !== '' || body !== '') {
+			// if some attachments are not valid, we disable the 'send' button
+			var attachmentsValid = this.checkAllAttachmentsValid();
+			if ((to !== '' || subject !== '' || body !== '') && attachmentsValid) {
 				this.$('.submit-message').removeAttr('disabled');
 			} else {
 				this.$('.submit-message').attr('disabled', true);
@@ -288,7 +296,8 @@ define(function(require) {
 			bcc.prop('disabled', true);
 			subject.prop('disabled', true);
 			this.$('.new-message-attachments-action').css('display', 'none');
-			this.$('#mail_new_attachment').prop('disabled', true);
+			this.$('#add-cloud-attachment').prop('disabled', true);
+			this.$('#add-local-attachment').prop('disabled', true);
 			newMessageBody.prop('disabled', true);
 			newMessageSend.prop('disabled', true);
 			newMessageSend.val(t('mail', 'Sending …'));
@@ -297,7 +306,7 @@ define(function(require) {
 			// if available get account from drop-down list
 			if (this.$('.mail-account').length > 0) {
 				alias = this.findAliasById(this.$('.mail-account').
-				find(':selected').val());
+					find(':selected').val());
 				this.account = this.accounts.get(alias.accountId);
 			}
 
@@ -313,10 +322,17 @@ define(function(require) {
 				options.folder = this.folder;
 			}
 
-			var sendingMessage = Radio.message.request('send', this.account, this.getMessage(), options);
-			$.when(sendingMessage).done(function() {
+			Radio.message.request('send', this.account, this.getMessage(), options).then(function() {
 				OC.Notification.showTemporary(t('mail', 'Message sent!'));
 
+				if (!!options.repliedMessage) {
+					// Reply -> flag message as replied
+					Radio.message.trigger('flag',
+						options.repliedMessage,
+						'answered',
+						true);
+				}
+
 				_this.$('#mail_new_message').prop('disabled', false);
 				to.val('');
 				cc.val('');
@@ -333,8 +349,7 @@ define(function(require) {
 					}
 					_this.draftUID = null;
 				}
-			});
-			$.when(sendingMessage).fail(function(jqXHR) {
+			}, function(jqXHR) {
 				var error = '';
 				if (jqXHR.status === 500) {
 					error = t('mail', 'Server error');
@@ -344,8 +359,7 @@ define(function(require) {
 				}
 				newMessageSend.prop('disabled', false);
 				OC.Notification.showTemporary(error);
-			});
-			$.when(sendingMessage).always(function() {
+			}).then(function() {
 				// remove loading feedback
 				newMessageBody.removeClass('icon-loading');
 				_this.$('.mail-account').prop('disabled', false);
@@ -355,7 +369,8 @@ define(function(require) {
 				subject.prop('disabled', false);
 				_this.$('.new-message-attachments-action').
 					css('display', 'inline-block');
-				_this.$('#mail_new_attachment').prop('disabled', false);
+				_this.$('#add-cloud-attachment').prop('disabled', false);
+				_this.$('#add-local-attachment').prop('disabled', false);
 				newMessageBody.prop('disabled', false);
 				newMessageSend.prop('disabled', false);
 				newMessageSend.val(t('mail', 'Send'));
@@ -374,26 +389,32 @@ define(function(require) {
 			// if available get account from drop-down list
 			if (this.$('.mail-account').length > 0) {
 				var alias = this.findAliasById(this.$('.mail-account').
-				find(':selected').val());
+					find(':selected').val());
 				this.account = this.accounts.get(alias.accountId);
 			}
 
 			// send the mail
 			var _this = this;
-			var savingDraft = Radio.message.request('draft', this.account, this.getMessage(), {
-				folder: this.folder,
-				repliedMessage: this.repliedMessage,
-				draftUID: this.draftUID
-			});
-			$.when(savingDraft).done(function(data) {
+			Radio.message.request('draft', this.account, this.getMessage(), {
+				folder: _this.folder,
+				repliedMessage: _this.repliedMessage,
+				draftUID: _this.draftUID
+			}).then(function(data) {
 				if (_.isFunction(onSuccess)) {
 					onSuccess();
 				}
+
+				if (_this.draftUID !== null) {
+					// update UID in message list
+					var collection = Radio.ui.request('messagesview:collection');
+					var message = collection.findWhere({id: _this.draftUID});
+					if (message) {
+						message.set({id: data.uid});
+						collection.set([message], {remove: false});
+					}
+				}
 				_this.draftUID = data.uid;
-			});
-			$.when(savingDraft).fail(function() {
-				// TODO: show error
-			});
+			}, console.error.bind(this));
 			return false;
 		},
 		setReplyBody: function(from, date, text) {
@@ -475,7 +496,9 @@ define(function(require) {
 						this.value = terms.join(', ');
 						return false;
 					}
-				}).data('ui-autocomplete')._renderItem = function($ul, item) {
+				}).
+					data('ui-autocomplete')._renderItem = function(
+					$ul, item) {
 					var $item = $('<li/>');
 					var $row = $('<a/>');
 
@@ -539,30 +562,59 @@ define(function(require) {
 			return aliases;
 		},
 		findAliasById: function(id) {
-			return _.find(this.aliases, function(alias) { return parseInt(alias.id)  === parseInt(id); });
+			return _.find(this.aliases, function(alias) {
+				return parseInt(alias.id) === parseInt(id);
+			});
 		},
 		defaultMailSelect: function() {
 			var alias = null;
 			if (!this.isReply()) {
 				if (require('state').currentAccount.get('accountId') !== -1) {
-					alias =  _.find(this.aliases, function(alias) {
-						return alias.emailAddress  === require('state').currentAccount.get('email');
+					alias = _.find(this.aliases, function(alias) {
+						return alias.emailAddress === require('state').currentAccount.get('email');
 					});
 				} else {
-					var firstAccount = this.accounts.filter(function(account) {
+					var firstAccount = this.accounts.filter(function(
+						account) {
 						return account.get('accountId') !== -1;
 					})[0];
 					alias = _.find(this.aliases, function(alias) {
-						return alias.emailAddress  === firstAccount.get('emailAddress');
+						return alias.emailAddress === firstAccount.get('emailAddress');
 					});
 				}
 			} else {
 				var toEmail = this.data.toEmail;
-				alias =  _.find(this.aliases, function(alias) {	return alias.emailAddress  === toEmail;	});
+				alias = _.find(this.aliases, function(alias) {
+					return alias.emailAddress === toEmail;
+				});
 			}
 			if (alias) {
-				$('.mail-account').val(alias.id);
+				this.$('.mail-account').val(alias.id);
 			}
+		},
+		/**
+		 * Checke that all attachments are valid.
+		 * If there is some LocalAttachments stil pending, ongoing or that failed,
+		 * This method will return false.
+		 * If there is no LocalAttachments, or if they are are all sent,
+		 * this method will return true.
+		 * @return {boolean} all attachments valid
+		 */
+		checkAllAttachmentsValid: function() {
+			var allAttachmentsValid = true;
+			var len = this.attachments.length;
+			for (var i = 0; i < len; i++) {
+				/* We check all the attachments here */
+				var attachment = this.attachments.models[i];
+				var uploadStatus = attachment.get('uploadStatus');
+				var isLocalUpload = (uploadStatus !== undefined);
+				/* If at least one attachment is a local upload and */
+				/* not a success (==3), we disable the send button */
+				if (isLocalUpload && uploadStatus < 3) {
+					allAttachmentsValid = false;
+				}
+			}
+			return allAttachmentsValid;
 		}
 	});
 
