@@ -3,12 +3,11 @@ OC.L10N.register(
     {
     "Mail" : "Mail",
     "Error while loading the accounts." : "Fejl under indlæsning af konti.",
-    "Fetching Aliases Failed." : "Hentning af aliases mislykkedes.",
-    "Saving Aliases Failed." : "Gemning af aliases misiykkedes.",
-    "Deleting Aliases Failed." : "Sletning af aliases mislykkedes.",
     "Error while loading the selected account." : "Der opstod en fejl under læsningen af den valgte konto.",
+    "Can not load this folder." : "Kan ikke indlæse denne mappe.",
     "Loading {folder}" : "Henter {folder}",
     "Searching for {query}" : "Leder efter {query}",
+    "Error while deleting message." : "Fejl under sletning af besked.",
     "Forwarded message" : "Videresendt besked",
     "Choose a folder to store the attachment in" : "Vælg den mappe, hvor vedhæftningen skal gemmes i",
     "Attachments saved to Files." : "Vedhæftning blev gemt i Filer.",
@@ -16,10 +15,12 @@ OC.L10N.register(
     "Error while saving attachments to Files." : "Fejl under lagring af vedhæftninger i Filer.",
     "Error while saving attachment to Files." : "Fejl under lagring af vedhæftninger i Filer.",
     "Message flag could not be set." : "Beskedflaget kunne ikke sættes.",
+    "Could not move message." : "Kunne ikke flytte beskeden.",
     "Invalid account" : "Ugyldig konto",
     "Invalid folder" : "Ugyldig mappe",
+    "Error while creating the account: " : "Fejl under oprettelse af kontoen:",
     "Unknown error" : "Ukendt fejl",
-    "Error while creating an account: " : "Fejl under oprettelse af kontoen:",
+    "All inboxes" : "Alle indbakker",
     "Could not load {tag}{name}{endtag}" : "Kunne ikke hente {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "Vi kunne ikke hente {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Der var et problem med at hente {tag}{name}{endtag}",
@@ -27,7 +28,6 @@ OC.L10N.register(
     "Unable to load the desired message" : "Ude af stand til at hente den ønskede mesked",
     "There was a problem loading the message" : "Der var et problem med at beskeden",
     "{from}\n{subject}" : "{fra}\n{emne}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n ny besked i {folderName}\nfra {from}","%n nye beskeder i {folderName}\nfra {from}"],
     "Show all folders" : "Vis all mappe",
     "Collapse folders" : "Fold mapper sammen",
     "Error while deleting account." : "Fejl under sletning af kontoen.",
@@ -45,10 +45,7 @@ OC.L10N.register(
     "No writable calendars found" : "Ingen skrivbare kalendre fundet",
     "Error while importing the calendar event" : "Fejl ved import af kalender begivenhed",
     "Error while downloading calendar event" : "Fejl ved hentning af kalender begivenhed",
-    "Error while deleting message." : "Fejl under sletning af besked.",
     "Error while loading messages." : "Fejl under indlæsning af beskeder.",
-    "Connecting" : "Tilslutter",
-    "Connect" : "Tilslut",
     "Inbox" : "Indbakke",
     "Sent" : "Sent",
     "Drafts" : "Udkast",
@@ -61,37 +58,26 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "Fejl ved autodetektion. Anvend venligst manuel opsætning",
     "Delete permanently" : "Slet permanent",
     "& others" : "& andre",
-    "All inboxes" : "Alle indbakker",
     "Error loading message" : "Fejl under indlæsning af besked",
+    "Settings" : "Indstillinger",
     "Forwarding to %s" : "Videre send til %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker at besøge denne side, kan du vende tilbage til <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Videre til %s",
-    "Settings" : "Indstillinger",
     "Delete account" : "Slet konto",
+    "Try again" : "Prøv igen",
+    "New message" : "Ny besked",
     "Account Settings" : "Konto indstillinger",
     "Aliases" : "Aliases",
     "Mail address" : "Mail addresse",
     "Display Name" : "Vist navn",
     "Save" : "Gem",
-    "Add attachment from Files" : "Vedhæft fra filer",
-    "from" : "fra",
-    "to" : "til",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Subject" : "Emne",
-    "Import into calendar" : "Importere til kalender",
-    "Download attachment" : "Hent vedhæftning",
-    "Save to Files" : "Gem til filer",
-    "Save all to Files" : "Gem alle filer",
-    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
-    "Show images from this sender" : "Vis billeder fra denne afsender",
-    "Forward" : "Videre send",
-    "New message" : "Ny besked",
-    "No search results for" : "Ingen søge resultater for",
-    "Add mail account" : "Tilføj mail konto",
+    "Keyboard shortcuts" : "Tastaturgenveje",
+    "Delete" : "Slet",
+    "Search" : "Søg",
+    "Refresh" : "Opdatér",
     "Connect your mail account" : "Forbind din mail konto",
     "Name" : "Navn",
     "Mail Address" : "Email addresse",
@@ -108,6 +94,21 @@ OC.L10N.register(
     "SMTP security" : "SMTP sikkerhed",
     "SMTP Port" : "SMTP port",
     "SMTP User" : "SMTP bruger",
-    "SMTP Password" : "SMTP kodeord"
+    "SMTP Password" : "SMTP kodeord",
+    "Connect" : "Tilslut",
+    "from" : "fra",
+    "to" : "til",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Emne",
+    "Save all to Files" : "Gem alle filer",
+    "Add mail account" : "Tilføj mail konto",
+    "No search results for" : "Ingen søge resultater for",
+    "The images have been blocked to protect your privacy." : "Dette billede er blevet blokeret for at beskytte din privat liv",
+    "Show images from this sender" : "Vis billeder fra denne afsender",
+    "Forward" : "Videre send",
+    "Import into calendar" : "Importere til kalender",
+    "Download attachment" : "Hent vedhæftning",
+    "Save to Files" : "Gem til filer"
 },
 "nplurals=2; plural=(n != 1);");
