@@ -1,25 +1,26 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "Mail",
+    "Mail" : "E-Mail",
     "Error while loading the accounts." : "Fehler beim Laden der Konten.",
-    "Fetching Aliases Failed." : "Fehler beim Ermitteln des Aliases",
-    "Saving Aliases Failed." : "Fehler beim Speichern des Aliases",
-    "Deleting Aliases Failed." : "Fehler beim Löschen des Aliases",
     "Error while loading the selected account." : "Fehler beim Laden des ausgewählten Kontos.",
+    "Can not load this folder." : "Dieser Ordner kann nicht geladen werden.",
     "Loading {folder}" : "Lade {folder}",
     "Searching for {query}" : "Suche nach {query}",
+    "Error while deleting message." : "Fehler beim Löschen der Nachricht.",
     "Forwarded message" : "Weitergeleitete Nachricht",
     "Choose a folder to store the attachment in" : "Ordner zum Speichern des Anhangs auswählen",
     "Attachments saved to Files." : "Anhänge wurde in Dateien gespeichert.",
     "Attachment saved to Files." : "Anhang wurde in Dateien gespeichert.",
-    "Error while saving attachments to Files." : "Fehler beim Speichern der Anhänge.",
-    "Error while saving attachment to Files." : "Fehler beim Speichern des Anhangs.",
+    "Error while saving attachments to Files." : "Fehler beim Speichern der Anhänge unter Dateien.",
+    "Error while saving attachment to Files." : "Fehler beim Speichern des Anhangs unter Dateien.",
     "Message flag could not be set." : "Nachrichten-Kennzeichnung konnte nicht gesetzt werden.",
-    "Invalid account" : "Ungültiges Nutzerkonto",
+    "Could not move message." : "Nachricht konnte nicht verschoben werden.",
+    "Invalid account" : "Ungültiges Benutzerkonto",
     "Invalid folder" : "Ungültiger Ordner",
+    "Error while creating the account: " : "Fehler beim Erstellen des Kontos:",
     "Unknown error" : "Unbekannter Fehler",
-    "Error while creating an account: " : "Fehler beim Erstellen eines Kontos:",
+    "All inboxes" : "Alle Posteingänge",
     "Could not load {tag}{name}{endtag}" : "Konnte {tag}{name}{endtag} nicht laden",
     "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag} konnte nicht geladen werden",
     "There was a problem loading {tag}{name}{endtag}" : "Beim Laden von {tag}{name}{endtag} ist ein Problem aufgetreten",
@@ -27,14 +28,14 @@ OC.L10N.register(
     "Unable to load the desired message" : "Gewünschte Nachricht konnte nicht geladen werden",
     "There was a problem loading the message" : "Beim Laden der Nachricht trat ein Fehler auf",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n neue Nachricht in {folderName} \nvon {from}","%n neue Nachrichten in {folderName} \nvon {from}"],
     "Show all folders" : "Alle Ordner anzeigen",
     "Collapse folders" : "Ordner einklappen",
     "Error while deleting account." : "Fehler beim Löschen des Kontos.",
     "Choose a file to add as attachment" : "Wählen Sie eine Datei, die als Anhang angefügt werden soll",
-    "Reply" : "Antwort",
+    "An error occurred while uploading {fname}" : "Fehler beim Hochladen von {fname} aufgetreten",
+    "Reply" : "Antworten",
     "Send" : "Senden",
-    "Sending …" : "Senden…",
+    "Sending …" : "Sende…",
     "Message sent!" : "Nachricht versandt!",
     "Server error" : "Serverfehler",
     "An unknown error occurred" : "Unbekannter Fehler aufgetreten",
@@ -45,10 +46,9 @@ OC.L10N.register(
     "No writable calendars found" : "Keine beschreibbaren Kalender gefunden",
     "Error while importing the calendar event" : "Fehler beim Importieren des Kalenderereignis",
     "Error while downloading calendar event" : "Fehler beim Herunterladen des Kalenderereignis",
-    "Error while deleting message." : "Fehler beim Löschen der Nachricht.",
     "Error while loading messages." : "Fehler beim Laden der Nachrichten.",
-    "Connecting" : "Verbinde",
-    "Connect" : "Verbinden",
+    "Error while refreshing messages." : "Fehler beim Aktualisieren der Nachrichten.",
+    "Setting up your account" : "Ihr Konto wird eingerichtet",
     "Inbox" : "Posteingang",
     "Sent" : "Gesendet",
     "Drafts" : "Entwürfe",
@@ -57,57 +57,69 @@ OC.L10N.register(
     "Junk" : "Spam",
     "All" : "Alle",
     "Favorites" : "Favoriten",
-    "Creating account failed: " : "Erstellung des Kontos ist fehlgeschlagen:",
+    "Creating account failed: " : "Kontoerstellung fehlgeschlagen:",
     "Auto detect failed. Please use manual mode." : "Automatische Erkennung fehlgeschlagen. Bitte nutzen Sie den manuellen Modus.",
     "Delete permanently" : "Endgültig löschen",
     "& others" : "& weitere",
-    "All inboxes" : "Alle Posteingänge",
     "Error loading message" : "Fehler beim Laden der Nachricht",
+    "Settings" : "Einstellungen",
     "Forwarding to %s" : "Weiterleiten an %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Hier klicken, wenn Sie nicht in wenigen Sekunden weitergeleitet werden.",
+    "Click here if you are not automatically redirected within the next few seconds." : "Hier klicken, wenn Sie nicht iautomatisch innerhalb der nächsten Sekunden weitergeleitet werden.",
     "Redirect" : "Weiterleiten",
     "The link leads to %s" : "Der Link führt nach %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Wenn Sie diese Seite nicht besuchen möchten, können Sie <a href=\"%s\">Mail</a> zurück kehren.",
-    "Continue to %s" : "Fortsetzen auf %s",
-    "Settings" : "Einstellungen",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Wenn Sie diese Seite nicht besuchen möchten, können Sie <a href=\"%s\">Mail</a> zurückkehren.",
+    "Continue to %s" : "Weiter nach %s",
     "Delete account" : "Konto löschen",
+    "Try again" : "Nochmals versuchen",
+    "New message" : "Neue Nachricht",
     "Account Settings" : "Konto-Einstellungen",
-    "Aliases" : "Aliase",
-    "Mail address" : "E-Mail Adresse",
+    "Aliases" : "Aliasse",
+    "Mail address" : "E-Mail-Adresse",
     "Display Name" : "Anzeigename",
     "Save" : "Speichern",
-    "Add attachment from Files" : "Anhang von Dateien hinzufügen",
+    "Keyboard shortcuts" : "Tastenkürzel",
+    "Speed up your Mail experience with these quick shortcuts." : "Verbessern Sie Ihre Arbeit mit Mail durch diese Schnellbefehle.",
+    "Compose new message" : "Neue Nachricht erstellen",
+    "Newer message" : "Neuere Nachricht",
+    "Older message" : "Ältere Nachricht",
+    "Toggle star" : "Stern umschalten",
+    "Toggle unread" : "Ungelesen umschalten",
+    "Delete" : "Löschen",
+    "Search" : "Suchen",
+    "Refresh" : "Aktualisieren",
+    "Connect your mail account" : "Verbinde Dein E-Mail-Konto",
+    "Name" : "Name",
+    "Mail Address" : "E-Mail-Adresse",
+    "Password" : "Passwort",
+    "Manual configuration" : "Manuelle Einrichtung",
+    "IMAP Host" : "IMAP-Host",
+    "IMAP security" : "IMAP-Sicherheit",
+    "None" : "Keine",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "IMAP-Port",
+    "IMAP User" : "IMAP-Benutzer",
+    "IMAP Password" : "IMAP-Passwort",
+    "SMTP Host" : "SMTP-Host",
+    "SMTP security" : "SMTP-Sicherheit",
+    "SMTP Port" : "SMTP-Port",
+    "SMTP User" : "SMTP-Benutzer",
+    "SMTP Password" : "SMTP-Passwort",
+    "Connect" : "Verbinden",
     "from" : "von",
-    "to" : "An",
+    "to" : "an",
     "cc" : "cc",
     "bcc" : "bcc",
     "Subject" : "Betreff",
+    "Save all to Files" : "Alles unter Dateien sichern",
+    "Add mail account" : "E-Mail-Konto hinzufügen",
+    "No search results for" : "Keine Suchergebnisse für",
+    "The images have been blocked to protect your privacy." : "Die Bilder wurden blockiert um Ihre Privatsphäre zu schützen.",
+    "Show images from this sender" : "Bilder dieses Absenders anzeigen",
+    "Forward" : "Weiterleiten",
+    "Add attachment" : "Anhang hinzufügen",
+    "Add from Files" : "Anhang hinzufügen",
     "Import into calendar" : "In Kalender importieren",
     "Download attachment" : "Anhang herunterladen",
-    "Save to Files" : "In Dateien speichern",
-    "Save all to Files" : "Alles in Dateien sichern",
-    "The images have been blocked to protect your privacy." : "Die Bilder sind blockiert worden, um Ihre Privatsphäre zu schützen",
-    "Show images from this sender" : "Bilder dieses Empfängers anzeigen",
-    "Forward" : "Weiterleiten",
-    "New message" : "Neue Nachricht",
-    "No search results for" : "Kein Suchergebnis für",
-    "Add mail account" : "E-Mail-Konto hinzufügen",
-    "Connect your mail account" : "Verbinde Dein E-Mail-Konto",
-    "Name" : "Name",
-    "Mail Address" : "E-Mail Adresse",
-    "Password" : "Passwort",
-    "Manual configuration" : "Manuelle Einrichtung",
-    "IMAP Host" : "IMAP Host",
-    "IMAP security" : "IMAP Sicherheit",
-    "None" : "Keine",
-    "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "IMAP Port",
-    "IMAP User" : "IMAP Benutzer",
-    "IMAP Password" : "IMAP Passwort",
-    "SMTP Host" : "SMTP Host",
-    "SMTP security" : "SMTP Sicherheit",
-    "SMTP Port" : "SMTP Port",
-    "SMTP User" : "SMTP Benutzer",
-    "SMTP Password" : "SMTP Passwort"
+    "Save to Files" : "Unter Dateien speichern"
 },
 "nplurals=2; plural=(n != 1);");
