@@ -3,98 +3,120 @@ OC.L10N.register(
     {
     "Mail" : "Αλληλογραφία",
     "Error while loading the accounts." : "Σφάλμα κατά τη φόρτωση των λογαριασμών.",
-    "Fetching Aliases Failed." : "Αποτυχία λήψης ψευδωνύμων.",
-    "Saving Aliases Failed." : "Αποτυχία αποθήκευσης ψευδωνύμων.",
-    "Deleting Aliases Failed." : "Αποτυχία διαγραφής ψευδωνύμων.",
     "Error while loading the selected account." : "Σφάλμα κατά τη φόρτωση του επιλεγμένου λογαριασμού.",
+    "Can not load this folder." : "Αδυναμία φόρτωσης αυτού του φακέλου.",
+    "Loading {folder}" : "Φόρτωση {folder}",
     "Searching for {query}" : "Αναζήτηση για {query}",
+    "Error while deleting message." : "Σφάλμα κατά τη διαγραφή του μηνύματος.",
     "Forwarded message" : "Προωθημένο μήνυμα",
-    "Choose a folder to store the attachment in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε τα συννημένα",
+    "Choose a folder to store the attachment in" : "Επιλέξτε ένα φάκελο για να αποθηκεύσετε τα συνημμένα",
     "Attachments saved to Files." : "Τα συνημμένα αποθηκεύτηκαν στα Έγγραφα.",
     "Attachment saved to Files." : "Το συνημμένο αποθηκεύτηκε στα Έγγραφα.",
     "Error while saving attachments to Files." : "Σφάλμα κατά την αποθήκευση των συνημμένων στα Έγγραφα.",
     "Error while saving attachment to Files." : "Σφάλμα κατά την αποθήκευση του συνημμένου στα Έγγραφα.",
     "Message flag could not be set." : "Δεν μπορεί να οριστεί η σημαία για το μήνυμα.",
+    "Could not move message." : "Αδυναμία μετακίνησης μηνύματος",
     "Invalid account" : "Μη έγκυρος λογαριασμός",
     "Invalid folder" : "Μη έγκυρος φάκελος",
+    "Error while creating the account: " : "Σφάλμα κατά τη δημιουργία του λογαριασμού:",
     "Unknown error" : "Άγνωστο σφάλμα",
-    "Error while creating an account: " : "Σφάλμα κατά τη δημιουργία λογαριασμού:",
+    "All inboxes" : "Όλα τα εισερχόμενα",
+    "Could not load {tag}{name}{endtag}" : "Αδυναμία φόρτωσης {tag}{name}{endtag}",
+    "We couldn’t load {tag}{name}{endtag}" : "Αδυναμία φόρτωσης {tag}{name}{endtag}",
+    "There was a problem loading {tag}{name}{endtag}" : "Παρουσιάστηκε πρόβλημα φόρτωσης {tag}{name}{endtag}",
+    "We couldn’t load your message" : "Δεν μπόρεσε να φορτωθεί το μήνυμά σας",
+    "Unable to load the desired message" : "Αδυναμία φόρτωσης του προτιμώμενου μηνύματος",
+    "There was a problem loading the message" : "Υπήρξε πρόβλημα φόρτωσης του μηνύματος",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n νέο μήνυμα σε {folderName}\nαπό {from}","%n νέα μηνύματα σε {folderName}\nαπό {from}"],
     "Show all folders" : "Εμφάνιση όλων των φακέλων",
     "Collapse folders" : "Σύμπτυξη φακέλων",
     "Error while deleting account." : "Σφάλμα κατά τη διαγραφή λογαριασμού.",
-    "Choose a file to add as attachment" : "Επιλέξτε έναν φάκελο για να προσθέσετε σαν συνημμένο",
+    "Choose a file to add as attachment" : "Επιλέξτε ένα αρχείο για να προσθέσετε ως συνημμένο",
     "Reply" : "Απάντηση",
     "Send" : "Αποστολή",
-    "Sending …" : "Αποστολή...",
+    "Sending …" : "Αποστέλλεται...",
     "Message sent!" : "Μήνυμα εστάλη!",
     "Server error" : "Σφάλμα διακομιστή",
-    "Opening HTML drafts is not supported yet." : "Το άνοιγμα HTML προχείρων  δεν υποστηρίζεται ακόμη.",
+    "An unknown error occurred" : "Προέκυψε ένα άγνωστο σφάλμα",
+    "Opening HTML drafts is not supported yet." : "Δεν υποστηρίζεται ακόμα το άνοιγμα προχείρων HTML.",
     "Draft saved!" : "Το πρόχειρο αποθηκεύτηκε!",
     "you" : "εσείς",
     "Send message to {email}" : "Αποστολή μηνύματος σε {email}",
     "No writable calendars found" : "Δεν βρέθηκαν εγγράψιμα ημερολόγια",
     "Error while importing the calendar event" : "Σφάλμα κατά την εισαγωγή γεγονότος στο ημερολόγιο",
-    "Error while downloading calendar event" : "Σφάλμα κατά την λήψη γεγονότος ημερολογίου",
-    "Error while deleting message." : "Σφάλμα κατά τη διαγραφή του μηνύματος",
+    "Error while downloading calendar event" : "Σφάλμα κατά την λήψη συμβάντος ημερολογίου",
     "Error while loading messages." : "Σφάλμα κατά τη φόρτωση μηνυμάτων.",
-    "Connecting" : "Σύνδεση",
-    "Connect" : "Σύνδεση",
+    "Setting up your account" : "Ρύθμιση του λογαριασμού σας",
     "Inbox" : "Εισερχόμενα",
     "Sent" : "Απεσταλμένα",
     "Drafts" : "Πρόχειρα",
     "Archive" : "Αρχείο",
-    "Trash" : "Κάδος",
+    "Trash" : "Απορρίμματα",
     "Junk" : "Ανεπιθύμητα",
     "All" : "Όλα",
     "Favorites" : "Αγαπημένα",
-    "Creating account failed: " : "Η δημιουργία λογαριασμού απέτυχε:",
-    "Auto detect failed. Please use manual mode." : " Η αυτόματη ανίχνευση απέτυχε. Παρακαλούμε χρησιμοποιήστε τη χειροκίνητη λειτουργία.",
+    "Creating account failed: " : "Αποτυχία δημιουργίας λογαριασμού:",
+    "Auto detect failed. Please use manual mode." : "Η αυτόματη ανίχνευση απέτυχε. Παρακαλούμε χρησιμοποιήστε τη χειροκίνητη λειτουργία.",
     "Delete permanently" : "Μόνιμη διαγραφή",
     "& others" : "& άλλοι",
-    "All inboxes" : "Όλα τα εισερχόμενα",
-    "Error loading message" : "Μήνυμα σφάλματος φόρτωσης",
+    "Error loading message" : "Σφάλμα φόρτωσης μηνύματος",
+    "Settings" : "Ρυθμίσεις",
     "Forwarding to %s" : "Προώθηση σε %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Κάντε κλικ εδώ εάν δεν ανακατευθυνθείτε αυτόματα μέσα σε λίγα δευτερόλεπτα.",
     "Redirect" : "Ανακατεύθυνση",
     "The link leads to %s" : "Αυτός ο σύνδεσμος οδηγεί στο %s",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Εάν δεν θέλετε να επισκεφθείτε την σελίδα, μπορείτε να επιστρέψετε στην <a href=\"%s\">Αλληλογραφία</a>.",
     "Continue to %s" : "Συνέχεια στο %s",
-    "Settings" : "Ρυθμίσεις",
     "Delete account" : "Διαγραφή λογαριασμού",
+    "Try again" : "Δοκιμάστε ξανά",
+    "New message" : "Νέο μήνυμα",
     "Account Settings" : "Ρυθμίσεις λογαριασμού",
     "Aliases" : "Ψευδώνυμα",
     "Mail address" : "Διεύθυνση αλληλογραφίας",
+    "Display Name" : "Εμφανιζόμενο όνομα",
     "Save" : "Αποθήκευση",
-    "Add attachment from Files" : "Προσθήκη συνημμένου από τα Αρχεία",
+    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
+    "Speed up your Mail experience with these quick shortcuts." : "Βελτιώστε την ταχύτητά σας στην εμπειρία χρήσης στο πρόγραμμα Αλληλογραφίας με αυτές τις συντομεύσεις.",
+    "Newer message" : "Νεότερο μήνυμα",
+    "Older message" : "Παλαιότερο μήνυμα",
+    "Toggle star" : "Εναλλαγή αστεριού",
+    "Toggle unread" : "Εναλλαγή αδιάβαστων",
+    "Delete" : "Διαγραφή",
+    "Search" : "Αναζήτηση",
+    "Refresh" : "Ανανέωση",
+    "Connect your mail account" : "Συνδέστε το λογαριασμό αλληλογραφίας σας",
+    "Name" : "Όνομα",
+    "Mail Address" : "Διεύθυνση αλληλογραφίας",
+    "Password" : "Συνθηματικό",
+    "Manual configuration" : "Χειροκίνητη ρύθμιση",
+    "IMAP Host" : "Υπολογιστής IMAP",
+    "IMAP security" : "Ασφάλεια IMAP",
+    "None" : "Κανένα",
+    "STARTTLS" : "STARTTLS",
+    "IMAP Port" : "Πόρτα IMAP",
+    "IMAP User" : "Χρήστης IMAP",
+    "IMAP Password" : "Συνθηματικό IMAP",
+    "SMTP Host" : "Υπολογιστής SMTP",
+    "SMTP security" : "Ασφάλεια SMTP",
+    "SMTP Port" : "Πόρτα SMTP",
+    "SMTP User" : "Χρήστης SMTP",
+    "SMTP Password" : "Συνθηματικό SMTP",
+    "Connect" : "Σύνδεση",
     "from" : "από",
     "to" : "προς",
     "cc" : "κοιν.",
     "bcc" : "κρυφή κοιν.",
     "Subject" : "Θέμα",
-    "Import into calendar" : "Εισαγωγή στο ημερολόγιο",
-    "Download attachment" : "Λήψη συνημμένου",
-    "Save to Files" : "Αποθήκευση στα Αρχεία",
     "Save all to Files" : "Αποθήκευση όλων στα Αρχεία",
+    "Add mail account" : "Προσθήκη λογαριασμού αλληλογραφίας",
+    "No search results for" : "Δεν βρέθηκαν αποτελέσματα για",
     "The images have been blocked to protect your privacy." : "Οι εικόνες έχουν αποκλειστεί για να προστατευθεί η ιδιωτικότητά σας.",
     "Show images from this sender" : "Εμφάνιση εικόνων από αυτόν τον αποστολέα",
     "Forward" : "Προώθηση",
-    "New message" : "Νέο μήνυμα",
-    "No search results for" : "Δεν βρέθηκαν αποτελέσματα για",
-    "Add mail account" : "Προσθήκη λογαριασμού αλληλογραφίας",
-    "Connect your mail account" : "Σύνδεση στον λογαριασμό αλληλογραφίας",
-    "Name" : "Όνομα",
-    "Mail Address" : "Διεύθυνση αλληλογραφίας",
-    "Password" : "Συνθηματικό",
-    "Manual configuration" : "Χειροκίνητη ρύθμιση",
-    "IMAP security" : "Ασφάλεια IMAP",
-    "None" : "Τίποτα",
-    "STARTTLS" : "STARTTLS",
-    "IMAP User" : "Χρήστης IMAP",
-    "IMAP Password" : "Συνθηματικό IMAP",
-    "SMTP security" : "Ασφάλεια SMTP",
-    "SMTP User" : "Χρήστης SMTP",
-    "SMTP Password" : "Συνθηματικό SMTP"
+    "Add attachment" : "Προσθήκη συνημμένου",
+    "Add from Files" : "Προσθήκη από τα Αρχεία",
+    "Import into calendar" : "Εισαγωγή στο ημερολόγιο",
+    "Download attachment" : "Λήψη συνημμένου",
+    "Save to Files" : "Αποθήκευση στα Αρχεία"
 },
 "nplurals=2; plural=(n != 1);");
