@@ -3,12 +3,11 @@ OC.L10N.register(
     {
     "Mail" : "Mail",
     "Error while loading the accounts." : "Erreur lors du chargement des comptes.",
-    "Fetching Aliases Failed." : "Échec de la récupération des Alias.",
-    "Saving Aliases Failed." : "Echec de la sauvergarde des Alias.",
-    "Deleting Aliases Failed." : "Échec de la suppression des Alias.",
     "Error while loading the selected account." : "Erreur lors du chargement du compte sélectionné.",
+    "Can not load this folder." : "Impossible de charger ce dossier.",
     "Loading {folder}" : "Chargement de {folder}",
     "Searching for {query}" : "Recherche pour {query}",
+    "Error while deleting message." : "Erreur lors de la suppression du message.",
     "Forwarded message" : "Message transféré",
     "Choose a folder to store the attachment in" : "Choisissez le dossier dans lequel enregistrer la pièce jointe",
     "Attachments saved to Files." : "Pièces jointes enregistrées dans les Fichiers.",
@@ -16,10 +15,12 @@ OC.L10N.register(
     "Error while saving attachments to Files." : "Erreur lors de l'enregistrement des pièces jointes dans les Fichiers.",
     "Error while saving attachment to Files." : "Erreur lors de l'enregistrement de la pièce jointe dans les Fichiers.",
     "Message flag could not be set." : "Le drapeau n'a pas été ajouté sur le message.",
+    "Could not move message." : "Impossible de déplacer le message.",
     "Invalid account" : "Compte invalide",
     "Invalid folder" : "Dossier invalide",
+    "Error while creating the account: " : "Erreur lors de la création du compte:",
     "Unknown error" : "Erreur inconnue",
-    "Error while creating an account: " : "Erreur lors de la création du compte :",
+    "All inboxes" : "Toutes les boîtes",
     "Could not load {tag}{name}{endtag}" : "Impossible de charger {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "Nous ne pouvons pas charger {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Il y a eu un problème de chargement {tag}{name}{endtag}",
@@ -27,11 +28,11 @@ OC.L10N.register(
     "Unable to load the desired message" : "Impossible de charger le message souhaité",
     "There was a problem loading the message" : "Il y a eu un problème de chargement du message",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n nouveau message dans {folderName}\nde {from}","%n nouveaux messages dans {folderName}\nde {from}"],
     "Show all folders" : "Montrer tous les dossiers",
     "Collapse folders" : "Replier les dossiers",
     "Error while deleting account." : "Erreur lors de la suppression du compte.",
     "Choose a file to add as attachment" : "Choisissez un fichier à joindre au message",
+    "An error occurred while uploading {fname}" : "Une erreur est survenue lors du téléversement de la pièce-jointe {fname}",
     "Reply" : "Répondre",
     "Send" : "Envoyer",
     "Sending …" : "Envoi…",
@@ -45,10 +46,8 @@ OC.L10N.register(
     "No writable calendars found" : "Aucun calendrier modifiable n'a été trouvé",
     "Error while importing the calendar event" : "Erreur pendant l'importation de l'évènement du calendrier",
     "Error while downloading calendar event" : "Erreur pendant le téléchargement de l'évènement du calendrier",
-    "Error while deleting message." : "Erreur lors de la suppression du message.",
     "Error while loading messages." : "Erreur lors du chargement des messages.",
-    "Connecting" : "Connexion…",
-    "Connect" : "Connecter",
+    "Setting up your account" : "Paramétrage de votre compte",
     "Inbox" : "Boîte de réception",
     "Sent" : "Envoyés",
     "Drafts" : "Brouillons",
@@ -61,37 +60,32 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "L'auto-détection a échoué. Veuillez utiliser le mode manuel.",
     "Delete permanently" : "Supprimer définitivement",
     "& others" : "et d'autres",
-    "All inboxes" : "Toutes les boîtes",
     "Error loading message" : "Erreur lors du chargement du message",
+    "Settings" : "Paramètres",
     "Forwarding to %s" : "Faire suivre à %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Cliquer ici si vous n'êtes pas automatiquement redirigé dans les prochaines secondes.",
     "Redirect" : "Redirection",
     "The link leads to %s" : "Le lien dirige vers %s",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si vous ne désirez pas visiter cette page, vous pouvez retourner aux <a href=\"%s\">Mails</a>.",
     "Continue to %s" : "Continuer vers %s",
-    "Settings" : "Paramètres",
     "Delete account" : "Supprimer le compte",
+    "Try again" : "Réessayez",
+    "New message" : "Nouveau message",
     "Account Settings" : "Paramètres du compte",
     "Aliases" : "Alias",
     "Mail address" : "Adresse mail",
     "Display Name" : "Nom affiché",
     "Save" : "Sauvegarder",
-    "Add attachment from Files" : "Ajouter des pièces jointes depuis des Fichiers",
-    "from" : "de",
-    "to" : "à",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Subject" : "Sujet",
-    "Import into calendar" : "Importer dans le calendrier",
-    "Download attachment" : "Télécharger les pièces jointes",
-    "Save to Files" : "Enregistrer dans Fichiers",
-    "Save all to Files" : "Enregistrer tout dans les Fichier",
-    "The images have been blocked to protect your privacy." : "Les images ont été bloquées pour protéger votre vie privée.",
-    "Show images from this sender" : "Voir les images de cet expéditeur",
-    "Forward" : "Faire suivre",
-    "New message" : "Nouveau message",
-    "No search results for" : "Aucun résultats pour",
-    "Add mail account" : "Ajouter un compte mail",
+    "Keyboard shortcuts" : "Raccourcis clavier",
+    "Speed up your Mail experience with these quick shortcuts." : "Accélérez votre expérience Mail avec ces raccourcis rapides.",
+    "Compose new message" : "Rédigez un nouveau message",
+    "Newer message" : "Message plus récent",
+    "Older message" : "Message plus ancien",
+    "Toggle star" : "Épingler / Désépingler",
+    "Toggle unread" : "Basculer en lu/non lu",
+    "Delete" : "Supprimer",
+    "Search" : "Rechercher",
+    "Refresh" : "Rafraîchir",
     "Connect your mail account" : "Connecter votre compte mail",
     "Name" : "Nom",
     "Mail Address" : "Adresse mail",
@@ -108,6 +102,23 @@ OC.L10N.register(
     "SMTP security" : "Sécurité SMTP",
     "SMTP Port" : "Port SMTP",
     "SMTP User" : "Utilisateur SMTP",
-    "SMTP Password" : "Mot de passe SMTP"
+    "SMTP Password" : "Mot de passe SMTP",
+    "Connect" : "Connecter",
+    "from" : "de",
+    "to" : "vers",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Sujet",
+    "Save all to Files" : "Enregistrer tout dans les Fichiers",
+    "Add mail account" : "Ajouter un compte mail",
+    "No search results for" : "Aucun résultats pour",
+    "The images have been blocked to protect your privacy." : "Les images ont été bloquées pour protéger votre vie privée.",
+    "Show images from this sender" : "Voir les images de cet expéditeur",
+    "Forward" : "Faire suivre",
+    "Add attachment" : "Ajouter une pièce-jointe",
+    "Add from Files" : "Ajouter depuis Fichiers",
+    "Import into calendar" : "Importer dans le calendrier",
+    "Download attachment" : "Télécharger les pièces jointes",
+    "Save to Files" : "Enregistrer dans Fichiers"
 },
 "nplurals=2; plural=(n > 1);");
