@@ -3,23 +3,22 @@ OC.L10N.register(
     {
     "Mail" : "메일",
     "Error while loading the accounts." : "계정을 불러오는 중 오류가 발생했습니다.",
-    "Fetching Aliases Failed." : "별칭 가져오기 오류",
-    "Saving Aliases Failed." : "별칭 저장 오류",
-    "Deleting Aliases Failed." : "별칭 삭제 오류",
     "Error while loading the selected account." : "선택한 계정을 불러오는 중 오류가 발생했습니다.",
     "Loading {folder}" : "{folder} 불러오는 중...",
     "Searching for {query}" : "{query} 검색",
+    "Error while deleting message." : "메시지를 삭제하는 중 오류가 발생했습니다.",
     "Forwarded message" : "전달된 메시지",
     "Choose a folder to store the attachment in" : "첨부 항목을 저장할 폴더 선택",
     "Attachments saved to Files." : "첨부 파일이 클라우드에 저장되었습니다.",
     "Attachment saved to Files." : "첨부 파일이 클라우드에 저장되었습니다.",
     "Error while saving attachments to Files." : "첨부 파일을 클라우드에 저장하는 중 오류가 발생했습니다.",
     "Error while saving attachment to Files." : "첨부 파일을 클라우드에 저장하는 중 오류가 발생했습니다.",
-    "Message flag could not be set." : "메시지 플래그를 설정 할 수 없습니다.",
+    "Message flag could not be set." : "메시지 플래그를 설정할 수 없습니다.",
+    "Could not move message." : "메시지를 이동할 수 없습니다.",
     "Invalid account" : "잘못된 계정",
     "Invalid folder" : "잘못된 폴더",
     "Unknown error" : "알 수 없는 오류",
-    "Error while creating an account: " : "계정을 만드는 중 오류 발생: ",
+    "All inboxes" : "모든 받은 편지함",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
     "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러올 수 없음",
     "There was a problem loading {tag}{name}{endtag}" : "{tag}{name}{endtag}을(를) 불러오는 중 문제 발생",
@@ -27,7 +26,6 @@ OC.L10N.register(
     "Unable to load the desired message" : "원하는 메시지를 불러올 수 없음",
     "There was a problem loading the message" : "메시지를 불러오는 중 문제가 발생했습니다",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["{folderName}에 {from} 님이 보낸 \n새 메시지 %n개"],
     "Show all folders" : "모든 폴더 보기",
     "Collapse folders" : "폴더 접기",
     "Error while deleting account." : "계정을 삭제하는 중 오류가 발생했습니다.",
@@ -45,10 +43,7 @@ OC.L10N.register(
     "No writable calendars found" : "쓰기 가능한 달력을 찾을 수 없음",
     "Error while importing the calendar event" : "달력 이벤트를 가져 오는 중 오류 발생",
     "Error while downloading calendar event" : "달력 이벤트 다운로드 중 오류 발생",
-    "Error while deleting message." : "메시지를 삭제하는 중 오류 발생",
-    "Error while loading messages." : "메시지를 불러오는 중 오류 발생",
-    "Connecting" : "연결 중",
-    "Connect" : "연결",
+    "Error while loading messages." : "메시지를 불러오는 중 오류가 발생했습니다.",
     "Inbox" : "받은 편지함",
     "Sent" : "보낸 편지함",
     "Drafts" : "임시 보관함",
@@ -61,37 +56,21 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "자동 감지가 실패했습니다. 수동 모드를 사용하십시오.",
     "Delete permanently" : "영구히 삭제",
     "& others" : "및 그 외",
-    "All inboxes" : "모든 받은 편지함",
     "Error loading message" : "메시지 불러오기 오류",
+    "Settings" : "설정",
     "Forwarding to %s" : "%s 전달",
     "Click here if you are not automatically redirected within the next few seconds." : "자동으로 이동하지 않는 경우 여기를 클릭하십시오.",
     "Redirect" : "리디렉션",
     "The link leads to %s" : "링크는 %s(으)로 연결",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
     "Continue to %s" : "%s(으)로 이동",
-    "Settings" : "설정",
     "Delete account" : "계정 삭제",
+    "New message" : "새로운 메시지",
     "Account Settings" : "계정 설정",
     "Aliases" : "별칭",
     "Mail address" : "메일 주소",
     "Display Name" : "표시 이름",
     "Save" : "저장",
-    "Add attachment from Files" : "파일에서 첨부파일 추가",
-    "from" : "에서",
-    "to" : "으로",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Subject" : "제목",
-    "Import into calendar" : "달력으로 가져 오기",
-    "Download attachment" : "첨부파일 다운로드",
-    "Save to Files" : "파일에 저장",
-    "Save all to Files" : "모두 저장",
-    "The images have been blocked to protect your privacy." : "이미지는 개인 정보를 보호하기 위해 차단되었습니다.",
-    "Show images from this sender" : "발신자 이미지 표시",
-    "Forward" : "전달",
-    "New message" : "새로운 메시지",
-    "No search results for" : "에 대한 검색 결과 없음",
-    "Add mail account" : "메일 계정 추가",
     "Connect your mail account" : "메일 계정에 연결",
     "Name" : "이름",
     "Mail Address" : "메일 주소",
@@ -108,6 +87,21 @@ OC.L10N.register(
     "SMTP security" : "SMTP 보안",
     "SMTP Port" : "SMTP 포트",
     "SMTP User" : "SMTP 사용자",
-    "SMTP Password" : "SMTP 암호"
+    "SMTP Password" : "SMTP 암호",
+    "Connect" : "연결",
+    "from" : "보낸 사람",
+    "to" : "받는 사람",
+    "cc" : "참조",
+    "bcc" : "숨은 참조",
+    "Subject" : "제목",
+    "Save all to Files" : "모두 저장",
+    "Add mail account" : "메일 계정 추가",
+    "No search results for" : "다음에 대한 검색 결과 없음",
+    "The images have been blocked to protect your privacy." : "개인 정보를 보호하기 위해 사진을 차단했습니다.",
+    "Show images from this sender" : "이 발신자의 사진 표시",
+    "Forward" : "전달",
+    "Import into calendar" : "달력으로 가져오기",
+    "Download attachment" : "첨부 파일 다운로드",
+    "Save to Files" : "파일에 저장"
 },
 "nplurals=1; plural=0;");
