@@ -3,12 +3,11 @@ OC.L10N.register(
     {
     "Mail" : "E-mail",
     "Error while loading the accounts." : "Fout tijdens het laden van de accounts.",
-    "Fetching Aliases Failed." : "Ophalen Aliassen mislukt.",
-    "Saving Aliases Failed." : "Bewaren Aliassen mislukt.",
-    "Deleting Aliases Failed." : "Verwijderen Aliassen mislukt.",
     "Error while loading the selected account." : "Fout tijdens het laden van het gekozen account.",
+    "Can not load this folder." : "Kan deze map niet laden.",
     "Loading {folder}" : "Laden {folder}",
     "Searching for {query}" : "Zoeken naar {query}",
+    "Error while deleting message." : "Fout bij verwijderen bericht.",
     "Forwarded message" : "Doorgestuurd bericht",
     "Choose a folder to store the attachment in" : "Kies een map op de bijlage in op te slaan",
     "Attachments saved to Files." : "Bjilagen opgeslagen in Bestanden.",
@@ -16,10 +15,12 @@ OC.L10N.register(
     "Error while saving attachments to Files." : "Fout bij opslaan bijlagen in Bestanden.",
     "Error while saving attachment to Files." : "Fout bij opslaan bijlage in Bestanden.",
     "Message flag could not be set." : "Bericht kon niet als gemarkeerd worden.",
+    "Could not move message." : "Kon bericht niet verplaatsen",
     "Invalid account" : "Ongeldig account",
     "Invalid folder" : "Ongeldige map",
+    "Error while creating the account: " : "Fout bij het creëren van een account:",
     "Unknown error" : "Onbekende fout",
-    "Error while creating an account: " : "Fout bij het creëren van een account.",
+    "All inboxes" : "Alle postvakken",
     "Could not load {tag}{name}{endtag}" : "Kon niet laden {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "{tag}{name}{endtag} kon niet worden geladen",
     "There was a problem loading {tag}{name}{endtag}" : "Er is een probleem bij het laden {tag}{name}{endtag}",
@@ -27,11 +28,11 @@ OC.L10N.register(
     "Unable to load the desired message" : "Gewenste bericht kon niet worden geladen",
     "There was a problem loading the message" : "Het laden van het bericht was problematisch",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n nieuw bericht in {folderName} \nvan {from}","%n nieuwe berichten in {folderName} \nvan {from}"],
     "Show all folders" : "Laat alle mappen zien",
     "Collapse folders" : "Mappen inklappen",
     "Error while deleting account." : "Fout bij verwijderen account.",
     "Choose a file to add as attachment" : "Kies een bestand om als bijlage toe te voegen",
+    "An error occurred while uploading {fname}" : "Er trad een fout op bij het uploaden van {fname}",
     "Reply" : "Antwoord",
     "Send" : "Versturen",
     "Sending …" : "Versturen ...",
@@ -40,15 +41,13 @@ OC.L10N.register(
     "An unknown error occurred" : "Een onbekend probleem vond plaats",
     "Opening HTML drafts is not supported yet." : "Openen concept HTML wordt nog niet ondersteund.",
     "Draft saved!" : "Concept opgeslagen!",
-    "you" : "je",
-    "Send message to {email}" : "Versturen bericht naar {e-mail}",
+    "you" : "jou",
+    "Send message to {email}" : "Verstuur email aan {email}",
     "No writable calendars found" : "Geen beschijfbare agenda's gevonden",
     "Error while importing the calendar event" : "Fout bij importeren agenda-afspraak",
     "Error while downloading calendar event" : "Fout bij downloaden agenda-afspraak",
-    "Error while deleting message." : "Fout bij verwijderen bericht.",
     "Error while loading messages." : "Fout bij laden berichten.",
-    "Connecting" : "Verbinden",
-    "Connect" : "Verbinden",
+    "Setting up your account" : "Je account opzetten",
     "Inbox" : "Postvak in",
     "Sent" : "Verzonden",
     "Drafts" : "Concepten",
@@ -61,37 +60,32 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "Automatisch vaststellen mislukt. Gebruik handmatige modus.",
     "Delete permanently" : "Definitief verwijderen",
     "& others" : "& anderen",
-    "All inboxes" : "Alle postvakken",
     "Error loading message" : "Fout bij laden bericht",
+    "Settings" : "Instellingen",
     "Forwarding to %s" : "Doorsturen aan %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch worden doorgestuurd.",
+    "Click here if you are not automatically redirected within the next few seconds." : "Klik hier als je binnen enkele seconden niet automatisch wordt doorgestuurd.",
     "Redirect" : "Omleiden",
     "The link leads to %s" : "De link verwijst naar %s",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Als u die pagina niet wilt bezoeken, kunt u teruggaan naar <a href=\"%s\">E-mail</a>.",
     "Continue to %s" : "Verder naar %s",
-    "Settings" : "Instellingen",
     "Delete account" : "Verwijder account",
+    "Try again" : "Probeer opnieuw",
+    "New message" : "Nieuw bericht",
     "Account Settings" : "Account instellingen",
     "Aliases" : "Aliassen",
     "Mail address" : "E-mailadres",
     "Display Name" : "Weergavenaam",
     "Save" : "Opslaan",
-    "Add attachment from Files" : "Voeg bijlage toe uit bestanden",
-    "from" : "van",
-    "to" : "aan",
-    "cc" : "cc",
-    "bcc" : "bcc",
-    "Subject" : "Onderwerp",
-    "Import into calendar" : "Toevoegen aan agenda",
-    "Download attachment" : "Download bijlage",
-    "Save to Files" : "Opslaan in Bestanden",
-    "Save all to Files" : "Sla alles op in Bestanden",
-    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om uw privacy te beschermen",
-    "Show images from this sender" : "Laat afbeeldingen zien van deze afzender",
-    "Forward" : "Doorsturen",
-    "New message" : "Nieuw bericht",
-    "No search results for" : "Geen resultaten gevonden voor",
-    "Add mail account" : "Voeg e-mail account toe",
+    "Keyboard shortcuts" : "Sneltoetsen",
+    "Speed up your Mail experience with these quick shortcuts." : "Versnel je e-mail-ervaring met deze handige snelkoppelingen.",
+    "Compose new message" : "Opstellen nieuw bericht",
+    "Newer message" : "Recenter bericht",
+    "Older message" : "Ouder bericht",
+    "Toggle star" : "Omschakelen ster",
+    "Toggle unread" : "Omschakelen ongelezen",
+    "Delete" : "Verwijderen",
+    "Search" : "Zoeken",
+    "Refresh" : "Verversen",
     "Connect your mail account" : "verbind je e-mailaccount",
     "Name" : "Naam",
     "Mail Address" : "E-mailadres",
@@ -108,6 +102,23 @@ OC.L10N.register(
     "SMTP security" : "SMTP security",
     "SMTP Port" : "SMTP poort",
     "SMTP User" : "SMTP gebruikersnaam",
-    "SMTP Password" : "SMTP wachtwoord"
+    "SMTP Password" : "SMTP wachtwoord",
+    "Connect" : "Verbinden",
+    "from" : "van",
+    "to" : "aan",
+    "cc" : "cc",
+    "bcc" : "bcc",
+    "Subject" : "Onderwerp",
+    "Save all to Files" : "Sla alles op in Bestanden",
+    "Add mail account" : "Voeg e-mail account toe",
+    "No search results for" : "Geen resultaten gevonden voor",
+    "The images have been blocked to protect your privacy." : "De afbeeldingen zijn geblokkeerd om jouw privacy te beschermen",
+    "Show images from this sender" : "Laat afbeeldingen zien van deze afzender",
+    "Forward" : "Doorsturen",
+    "Add attachment" : "Toevoegen bijlage",
+    "Add from Files" : "Toevoegen uit bestanden",
+    "Import into calendar" : "Toevoegen aan agenda",
+    "Download attachment" : "Download bijlage",
+    "Save to Files" : "Opslaan in Bestanden"
 },
 "nplurals=2; plural=(n != 1);");
