@@ -1,113 +1,125 @@
 OC.L10N.register(
     "mail",
     {
-    "Mail" : "EMail",
-    "Error while loading the accounts." : "Erro no carregamento das contas.",
-    "Fetching Aliases Failed." : "Falha na Obtenção de Aliases.",
-    "Saving Aliases Failed." : "Falha ao Salvar Aliases.",
-    "Deleting Aliases Failed." : "Falha ao Excluir Aliases.",
-    "Error while loading the selected account." : "Erro enquanto carregava a conta selecionada",
+    "Mail" : "E-mail",
+    "Error while loading the accounts." : "Erro ao carregar as contas.",
+    "Error while loading the selected account." : "Erro ao carregar a conta selecionada",
+    "Can not load this folder." : "Não foi possível carregar esta pasta.",
     "Loading {folder}" : "Carregando {folder}",
     "Searching for {query}" : "Pesquisando por {query}",
-    "Forwarded message" : "Mensagem redirecionada",
+    "Error while deleting message." : "Erro ao excluir mensagem.",
+    "Forwarded message" : "Mensagem encaminhada",
     "Choose a folder to store the attachment in" : "Escolha uma pasta para armazenar os anexos",
-    "Attachments saved to Files." : "Compartilhamentos salvos em Arquivos.",
-    "Attachment saved to Files." : "Compartilhamentos salvos em Arquivos.",
-    "Error while saving attachments to Files." : "Erro enquanto salvava compartilhamentos em Arquivos.",
-    "Error while saving attachment to Files." : "Erro enquanto salvava compartilhamentos em Arquivos.",
+    "Attachments saved to Files." : "Anexo salvos em Arquivos.",
+    "Attachment saved to Files." : "Anexo salvo em Arquivos.",
+    "Error while saving attachments to Files." : "Erro ao salvar anexos em Arquivos.",
+    "Error while saving attachment to Files." : "Erro ao salvar anexos em Arquivos.",
     "Message flag could not be set." : "Marcação da mensagem não pôde ser definida.",
+    "Could not move message." : "Não foi possível mover a mensagem.",
     "Invalid account" : "Conta inválida",
     "Invalid folder" : "Pasta inválida",
+    "Error while creating the account: " : "Erro ao criar a conta:",
     "Unknown error" : "Erro desconhecido",
-    "Error while creating an account: " : "Erro na criação da conta:",
+    "All inboxes" : "Todas as caixas de entrada",
     "Could not load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "Não foi possível carregar {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Ocorreu um problema ao carregar {tag}{name}{endtag}",
     "We couldn’t load your message" : "Não foi possível carregar sua mensagem",
-    "Unable to load the desired message" : "Não é possível carregar a mensagem desejada",
+    "Unable to load the desired message" : "Não foi possível carregar a mensagem desejada",
     "There was a problem loading the message" : "Ocorreu um problema ao carregar a mensagem",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n nova mensagem em {folderName}\nde {from}","%n novas mensagens em {folderName}\nde {from}"],
     "Show all folders" : "Mostrar todas as pastas",
     "Collapse folders" : "Esconder as pastas",
-    "Error while deleting account." : "Erro enquanto eliminava uma conta.",
+    "Error while deleting account." : "Erro ao excluir a conta.",
     "Choose a file to add as attachment" : "Escolha um arquivo para adicionar como anexo",
+    "An error occurred while uploading {fname}" : "Um erro ocorreu ao enviar {fname}",
     "Reply" : "Responder",
     "Send" : "Enviar",
-    "Sending …" : "Enviando ...",
+    "Sending …" : "Enviando...",
     "Message sent!" : "Mensagem enviada!",
     "Server error" : "Erro no servidor",
     "An unknown error occurred" : "Ocorreu um erro desconhecido",
-    "Opening HTML drafts is not supported yet." : "Abrir rascunhos do HTML ainda não é suportado.",
+    "Opening HTML drafts is not supported yet." : "A abertura de rascunhos do HTML ainda não é suportada.",
     "Draft saved!" : "Rascunho salvo!",
     "you" : "você",
     "Send message to {email}" : "Enviar mensagem para {email}",
     "No writable calendars found" : "Não foi encontrado nenhum calendário que possa ser editado",
     "Error while importing the calendar event" : "Erro ao importar o evento de calendário",
     "Error while downloading calendar event" : "Erro ao baixar evento de calendário",
-    "Error while deleting message." : "Erro enquanto apagava mensagem.",
-    "Error while loading messages." : "Erro no carregamento das mensagens.",
-    "Connecting" : "Conectando",
-    "Connect" : "Conectar",
+    "Error while loading messages." : "Erro ao carregar mensagens.",
+    "Error while refreshing messages." : "Erro ao atualizar as mensagens.",
+    "Setting up your account" : "Configurando sua conta",
     "Inbox" : "Caixa de Entrada",
-    "Sent" : "Enviar",
+    "Sent" : "Enviados",
     "Drafts" : "Rascunhos",
-    "Archive" : "Arquivo",
+    "Archive" : "Arquivados",
     "Trash" : "Lixeira",
     "Junk" : "Lixo",
     "All" : "Todos",
     "Favorites" : "Favoritos",
     "Creating account failed: " : "A criação de contas falhou:",
-    "Auto detect failed. Please use manual mode." : "Auto detecção falhou. Por favor use o modo manual.",
+    "Auto detect failed. Please use manual mode." : "A auto detecção falhou. Por favor use o modo manual.",
     "Delete permanently" : "Excluir permanentemente",
     "& others" : "& outros",
-    "All inboxes" : "Todas as caixas de entrada",
     "Error loading message" : "Erro carregando mensagem",
+    "Settings" : "Configurações",
     "Forwarding to %s" : "Encaminhando para %s",
-    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se voce não for redirecionado automaticamente em alguns segundos",
+    "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se você não for redirecionado automaticamente em alguns segundos",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "O link leva a %s",
-    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se você não quiser visitar essa página, você pode retornar ao <a href=\"%s\">eMail</a>.",
+    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Se você não quiser visitar essa página, você pode retornar ao <a href=\"%s\">e-mail</a>.",
     "Continue to %s" : "Continue para %s",
-    "Settings" : "Configurações",
-    "Delete account" : "Deletar conta",
+    "Delete account" : "Excluir conta",
+    "Try again" : "Tentar novamente",
+    "New message" : "Nova mensagem",
     "Account Settings" : "Configurações de conta",
     "Aliases" : "Apelido",
-    "Mail address" : "Endereço de email",
+    "Mail address" : "Endereço de e-mail",
     "Display Name" : "Nome",
     "Save" : "Salvar",
-    "Add attachment from Files" : "Adicionar anexos de arquivos",
-    "from" : "de",
-    "to" : "para",
-    "cc" : "cc",
-    "bcc" : "cco",
-    "Subject" : "Assunto",
-    "Import into calendar" : "Importar para o calendário",
-    "Download attachment" : "Download de anexo",
-    "Save to Files" : "Salvar para arquivos",
-    "Save all to Files" : "Salvar todos para arquivos",
-    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger sua privacidade",
-    "Show images from this sender" : "Mostre imagens desse remetente",
-    "Forward" : "Encaminhar",
-    "New message" : "Nova mensagem",
-    "No search results for" : "Nenhum resultado de busca para",
-    "Add mail account" : "Adicionar conta de email",
-    "Connect your mail account" : "Conectar a sua conta de email",
+    "Keyboard shortcuts" : "Atalhos de teclado",
+    "Speed up your Mail experience with these quick shortcuts." : "Acelere o uso de seu e-mail com estes atalhos rápidos.",
+    "Compose new message" : "Redigir nova mensagem",
+    "Newer message" : "Mensagem mais recente",
+    "Older message" : "Mensagem mais antiga",
+    "Toggle star" : "Alterna para estrela",
+    "Toggle unread" : "Alterna para não lido",
+    "Delete" : "Excluir",
+    "Search" : "Pesquisar",
+    "Refresh" : "Atualizar",
+    "Connect your mail account" : "Conectar sua conta de e-mail",
     "Name" : "Nome",
-    "Mail Address" : "Endereço de email",
+    "Mail Address" : "Endereço de e-mail",
     "Password" : "Senha",
     "Manual configuration" : "Configuração manual",
     "IMAP Host" : "Host IMAP",
     "IMAP security" : "Segurança IMAP",
     "None" : "Não",
     "STARTTLS" : "STARTTLS",
-    "IMAP Port" : "Porta IMAP",
+    "IMAP Port" : "Porto IMAP",
     "IMAP User" : "Usuário IMAP",
     "IMAP Password" : "Senha IMAP",
     "SMTP Host" : "Host SMTP",
     "SMTP security" : "Segurança SMTP",
-    "SMTP Port" : "Porta SMTP",
+    "SMTP Port" : "Porto SMTP",
     "SMTP User" : "Usuário SMTP",
-    "SMTP Password" : "Senha SMTP"
+    "SMTP Password" : "Senha SMTP",
+    "Connect" : "Conectar",
+    "from" : "de",
+    "to" : "para",
+    "cc" : "cc",
+    "bcc" : "cco",
+    "Subject" : "Assunto",
+    "Save all to Files" : "Salvar tudo para Arquivos",
+    "Add mail account" : "Adicionar conta de e-mail",
+    "No search results for" : "Nenhum resultado de busca para",
+    "The images have been blocked to protect your privacy." : "As imagens foram bloqueadas para proteger sua privacidade",
+    "Show images from this sender" : "Mostre imagens desse remetente",
+    "Forward" : "Encaminhar",
+    "Add attachment" : "Adicionar anexo",
+    "Add from Files" : "Adicionar a partir de Arquivos",
+    "Import into calendar" : "Importar para o calendário",
+    "Download attachment" : "Baixar anexo",
+    "Save to Files" : "Salvar para arquivos"
 },
 "nplurals=2; plural=(n > 1);");
