@@ -3,23 +3,24 @@ OC.L10N.register(
     {
     "Mail" : "Почта",
     "Error while loading the accounts." : "Ошибка при загрузке учётных записей",
-    "Fetching Aliases Failed." : "Ошибка при извлечении псевдонима",
-    "Saving Aliases Failed." : "Ошибка при сохранении псевдонма",
-    "Deleting Aliases Failed." : "Ошибка при удалении псевдонима",
     "Error while loading the selected account." : "Ошибка загрузки выбранного аккаунта.",
+    "Can not load this folder." : "Невозможно загрузить этот каталог.",
     "Loading {folder}" : "Загрузка {folder}",
     "Searching for {query}" : "Поиск {query}",
+    "Error while deleting message." : "Ошибка при удалении сообщения.",
     "Forwarded message" : "Пересланное сообщение",
     "Choose a folder to store the attachment in" : "Выберите каталог для хранения вложений",
-    "Attachments saved to Files." : "Вложения сохранены в Файлах",
-    "Attachment saved to Files." : "Вложение сохранено в Файлах",
-    "Error while saving attachments to Files." : "Ошибка сохранения вложений в Файлах.",
-    "Error while saving attachment to Files." : "Ошибка сохранения вложения в Файлах.",
+    "Attachments saved to Files." : "Вложения сохранены в файлах",
+    "Attachment saved to Files." : "Вложение сохранено в файлах",
+    "Error while saving attachments to Files." : "Ошибка сохранения вложений в файлах.",
+    "Error while saving attachment to Files." : "Ошибка сохранения вложения в файлах.",
     "Message flag could not be set." : "Не удалось установить флажок сообщения.",
+    "Could not move message." : "Невозможно переместить сообщение",
     "Invalid account" : "Неверная учётная запись",
-    "Invalid folder" : "Неверная папка",
+    "Invalid folder" : "Неверный каталог",
+    "Error while creating the account: " : "Ошибка при создании учётной записи:",
     "Unknown error" : "Неизвестная ошибка",
-    "Error while creating an account: " : "Ошибка при создании учётной записи:",
+    "All inboxes" : "Все входящие",
     "Could not load {tag}{name}{endtag}" : "Не может быть загружено {tag}{name}{endtag}",
     "We couldn’t load {tag}{name}{endtag}" : "Мы не можем загрузить {tag}{name}{endtag}",
     "There was a problem loading {tag}{name}{endtag}" : "Проблема при загрузке {tag}{name}{endtag}",
@@ -27,11 +28,11 @@ OC.L10N.register(
     "Unable to load the desired message" : "Невозможно загрузить данное сообщение",
     "There was a problem loading the message" : "Проблемы при загрузке сообщения",
     "{from}\n{subject}" : "{from}\n{subject}",
-    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n новое сообщение в {folderName} \nот {from}","%n новых сообщения в {folderName} \nот {from}","%n новых сообщений в {folderName} \nот {from}","%n новых сообщений в {folderName} \nот {from}"],
-    "Show all folders" : "Показать все папки",
-    "Collapse folders" : "Свернуть папки",
+    "Show all folders" : "Показать все каталоги",
+    "Collapse folders" : "Свернуть каталоги",
     "Error while deleting account." : "Ошибка при удалении учётной записи.",
     "Choose a file to add as attachment" : "Выбрать файл для вложения",
+    "An error occurred while uploading {fname}" : "При загрузке {fname} произошла ошибка",
     "Reply" : "Ответ",
     "Send" : "Отправить",
     "Sending …" : "Отправляется ...",
@@ -45,10 +46,8 @@ OC.L10N.register(
     "No writable calendars found" : "Календари доступные для записи не найдены",
     "Error while importing the calendar event" : "Ошибка при импорте календарного события",
     "Error while downloading calendar event" : "Ошибка при скачивании календарного события",
-    "Error while deleting message." : "Ошибка при удалении сообщения.",
     "Error while loading messages." : "Ошибка пр загрузке изображений.",
-    "Connecting" : "Соединение",
-    "Connect" : "Соединить",
+    "Setting up your account" : "Настраивается учётная запись",
     "Inbox" : "Входящие",
     "Sent" : "Отправленные",
     "Drafts" : "Черновики",
@@ -61,37 +60,32 @@ OC.L10N.register(
     "Auto detect failed. Please use manual mode." : "Не удалось определить настройки автоматически. Воспользуйтесь ручным режимом.",
     "Delete permanently" : "Удалить окончательно",
     "& others" : "и другие",
-    "All inboxes" : "Все входящие",
     "Error loading message" : "Ошибка при загрузке сообщения",
+    "Settings" : "Настройки",
     "Forwarding to %s" : "Пересылка на %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Нажмите здесь, если не запустилось автоматическое перенаправление в течение нескольких секунд.",
     "Redirect" : "Перенаправление",
     "The link leads to %s" : "Эта ссылка ведёт на %s",
     "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>.",
     "Continue to %s" : "Продолжать %s",
-    "Settings" : "Настройки",
     "Delete account" : "Удалить аккаунт",
+    "Try again" : "Попытаться снова",
+    "New message" : "Новое сообщение",
     "Account Settings" : "Настройки аккаунта",
     "Aliases" : "Псевдонимы",
     "Mail address" : "Почтовый адрес",
     "Display Name" : "Отображаемое имя",
     "Save" : "Сохранить",
-    "Add attachment from Files" : "Добавить вложение из файлов",
-    "from" : "от кого",
-    "to" : "кому",
-    "cc" : "копия",
-    "bcc" : "скрытая копия",
-    "Subject" : "Тема",
-    "Import into calendar" : "Импортировать в календарь",
-    "Download attachment" : "Скачать вложение",
-    "Save to Files" : "Сохранить в файлы",
-    "Save all to Files" : "Сохранить все в файлы",
-    "The images have been blocked to protect your privacy." : "Изображения были заблокированы для защиты вашей частной жизни.",
-    "Show images from this sender" : "Показать изображения от этого отправителя",
-    "Forward" : "Вперед",
-    "New message" : "Новое сообщение",
-    "No search results for" : "Ничего не найдено для",
-    "Add mail account" : "Добавить почтовый аккаунт",
+    "Keyboard shortcuts" : "Горячие клавиши",
+    "Speed up your Mail experience with these quick shortcuts." : "Ускорьте работу с почтой использованием этих сочетаний клавиш.",
+    "Compose new message" : "Создать новое сообщение",
+    "Newer message" : "Новейшее сообщение",
+    "Older message" : "Старейшее сообщение",
+    "Toggle star" : "Переключить отметку звёздочкой",
+    "Toggle unread" : "Переключить отметку прочтения",
+    "Delete" : "Удалить",
+    "Search" : "Поиск",
+    "Refresh" : "Обновить",
     "Connect your mail account" : "Подключить почтовый аккаунт",
     "Name" : "Имя",
     "Mail Address" : "E-mail адрес",
@@ -108,6 +102,23 @@ OC.L10N.register(
     "SMTP security" : "Безопасность SMTP",
     "SMTP Port" : "SMTP-порт",
     "SMTP User" : "Пользователь SMTP",
-    "SMTP Password" : "Пароль SMTP"
+    "SMTP Password" : "Пароль SMTP",
+    "Connect" : "Соединить",
+    "from" : "от кого",
+    "to" : "кому",
+    "cc" : "копия",
+    "bcc" : "скрытая копия",
+    "Subject" : "Тема",
+    "Save all to Files" : "Сохранить все в файлы",
+    "Add mail account" : "Добавить почтовый аккаунт",
+    "No search results for" : "Ничего не найдено для",
+    "The images have been blocked to protect your privacy." : "Изображения были заблокированы для защиты вашей частной жизни.",
+    "Show images from this sender" : "Показать изображения от этого отправителя",
+    "Forward" : "Вперед",
+    "Add attachment" : "Добавить вложение",
+    "Add from Files" : "Добавить из файлов",
+    "Import into calendar" : "Импортировать в календарь",
+    "Download attachment" : "Скачать вложение",
+    "Save to Files" : "Сохранить в файлы"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
