@@ -93,6 +93,10 @@ class Account implements IAccount {
 		$this->alias = null;
 	}
 
+	public function getMailAccount() {
+		return $this->account;
+	}
+
 	/**
 	 * @return int
 	 */
@@ -101,11 +105,10 @@ class Account implements IAccount {
 	}
 
 	/**
-	 * @param Alias $alias
+	 * @param Alias|null $alias
 	 * @return void
 	 */
 	public function setAlias($alias) {
-		$this->alias = new Alias();
 		$this->alias = $alias;
 	}
 
@@ -199,8 +202,12 @@ class Account implements IAccount {
 		$mail->addHeaders($headers);
 		$mail->setBody($message->getContent());
 
-		// Append attachments
-		foreach ($message->getAttachments() as $attachment) {
+		// Append cloud attachments
+		foreach ($message->getCloudAttachments() as $attachment) {
+			$mail->addMimePart($attachment);
+		}
+		// Append local attachments
+		foreach ($message->getLocalAttachments() as $attachment) {
 			$mail->addMimePart($attachment);
 		}
 
@@ -347,29 +354,7 @@ class Account implements IAccount {
 	 * @return array
 	 */
 	public function jsonSerialize() {
-		$folders = [];
-		$mailBoxes = $this->getMailboxes();
-		$mailBoxNames = array_map(function($mb) {
-			/** @var Mailbox $mb */
-			return $mb->getFolderId();
-		}, array_filter($mailBoxes, function($mb) {
-			/** @var Mailbox $mb */
-			return (!$mb instanceof SearchMailbox) && (!in_array('\noselect', $mb->attributes()));
-		}));
-
-		$status = $this->getImapConnection()->status($mailBoxNames);
-		foreach ($mailBoxes as $mailbox) {
-			$s = isset($status[$mailbox->getFolderId()]) ? $status[$mailbox->getFolderId()] : null;
-			$folders[] = $mailbox->serialize($this->getId(), $s);
-		}
-		$delimiter = reset($folders)['delimiter'];
-		return [
-			'id' => $this->getId(),
-			'email' => $this->getEMailAddress(),
-			'folders' => array_values($folders),
-			'specialFolders' => $this->getSpecialFoldersIds(),
-			'delimiter' => $delimiter,
-		];
+		return $this->account->toJson();
 	}
 
 	/**
@@ -518,6 +503,13 @@ class Account implements IAccount {
 		}
 	}
 
+	public function moveMessage($sourceFolderId, $messageId, $destFolderId) {
+		$this->getImapConnection()->copy($sourceFolderId, $destFolderId, [
+			'ids' => new \Horde_Imap_Client_Ids($messageId),
+			'move' => true,
+		]);
+	}
+
 	/**
 	 * 
 	 * @param int $messageId
@@ -688,74 +680,6 @@ class Account implements IAccount {
 	}
 
 	/**
-	 * @param $query
-	 * @return array
-	 */
-	public function getChangedMailboxes($query) {
-		$imp = $this->getImapConnection();
-		$allBoxes = $this->getMailboxes();
-		$allBoxesMap = [];
-		foreach ($allBoxes as $mb) {
-			$allBoxesMap[$mb->getFolderId()] = $mb;
-		}
-
-		// filter non existing mailboxes
-		$mailBoxNames = array_filter(array_keys($query), function($folderId) use ($allBoxesMap) {
-			return isset($allBoxesMap[$folderId]);
-		});
-
-		$status = $imp->status($mailBoxNames);
-
-		// filter for changed mailboxes
-		$changedBoxes = [];
-		foreach ($status as $folderId => $s) {
-			$uidValidity = $query[$folderId]['uidvalidity'];
-			$uidNext = $query[$folderId]['uidnext'];
-
-			if ($uidNext === $s['uidnext'] &&
-				$uidValidity === $s['uidvalidity']) {
-				continue;
-			}
-			// get unread messages
-			if (isset($allBoxesMap[$folderId])) {
-				/** @var Mailbox $m */
-				$m = $allBoxesMap[$folderId];
-				$role = $m->getSpecialRole();
-				if (is_null($role) || $role === 'inbox') {
-					$newMessages = $m->getMessagesSince($uidNext, $s['uidnext']);
-					// only trigger updates in case new messages are actually available
-					if (!empty($newMessages)) {
-						$changedBoxes[$folderId] = $m->serialize($this->getId(), $s);
-						$changedBoxes[$folderId]['messages'] = $newMessages;
-						$newUnreadMessages = array_filter($newMessages, function($m) {
-							return $m['flags']['unseen'];
-						});
-						$changedBoxes[$folderId]['newUnReadCounter'] = count($newUnreadMessages);
-					}
-				}
-			}
-		}
-
-		return $changedBoxes;
-	}
-
-	/**
-	 * @throws Horde_Imap_Client_Exception
-	 */
-	public function reconnect() {
-		$this->mailboxes = null;
-		if ($this->client) {
-			$this->client->close();
-			$this->client = null;
-		}
-		$this->getImapConnection();
-	}
-
-	/**
-	 * @return array
-	 */
-	public function getConfiguration() {
-		return $this->account->toJson();
 	}
 
 	/**
