@@ -22,6 +22,12 @@
 
 namespace OCA\Mail\AppInfo;
 
+use OCA\Mail\Contracts\IAttachmentService;
+use OCA\Mail\Contracts\IMailManager;
+use OCA\Mail\Contracts\IMailTransmission;
+use OCA\Mail\Service\Attachment\AttachmentService;
+use OCA\Mail\Service\MailManager;
+use OCA\Mail\Service\MailTransmission;
 use OCP\AppFramework\App;
 use OCP\Util;
 
@@ -30,11 +36,18 @@ class Application extends App {
 	public function __construct(array $urlParams = []) {
 		parent::__construct('mail', $urlParams);
 
+		$this->initializeAppContainer();
+	}
+
+	private function initializeAppContainer() {
 		$container = $this->getContainer();
 
 		$transport = $container->getServer()->getConfig()->getSystemValue('app.mail.transport', 'smtp');
 		$testSmtp = $transport === 'smtp';
 
+		$container->registerAlias(IMailManager::class, MailManager::class);
+		$container->registerAlias(IAttachmentService::class, AttachmentService::class);
+		$container->registerAlias(IMailTransmission::class, MailTransmission::class);
 		$container->registerService('OCP\ISession', function ($c) {
 			return $c->getServer()->getSession();
 		});
