@@ -40,10 +40,13 @@ use Horde_Mail_Rfc822_List;
 use Horde_Mime_Part;
 use JsonSerializable;
 use OC;
+use OCA\Mail\Db\LocalAttachment;
 use OCA\Mail\Service\Html;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\Files\File;
+use OCP\Files\SimpleFS\ISimpleFile;
 use OCP\Util;
+use function mb_convert_encoding;
 
 class IMAPMessage implements IMessage, JsonSerializable {
 
@@ -596,7 +599,7 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		$p->setContents($data);
 		$data = $p->getContents();
 
-		$data = iconv($p->getCharset(), 'utf-8//IGNORE', $data);
+		$data = mb_convert_encoding($data, 'UTF-8', $p->getCharset());
 		return $data;
 	}
 
@@ -611,7 +614,14 @@ class IMAPMessage implements IMessage, JsonSerializable {
 	/**
 	 * @return array
 	 */
-	public function getAttachments() {
+	public function getCloudAttachments() {
+		throw new Exception('not implemented');
+	}
+
+	/**
+	 * @return int[]
+	 */
+	public function getLocalAttachments() {
 		throw new Exception('not implemented');
 	}
 
@@ -622,6 +632,14 @@ class IMAPMessage implements IMessage, JsonSerializable {
 		throw new Exception('IMAP message is immutable');
 	}
 
+	/**
+	 * @param LocalAttachment $attachment
+	 * @param ISimpleFile $file
+	 */
+	public function addLocalAttachment(LocalAttachment $attachment, ISimpleFile $file) {
+		throw new Exception('IMAP message is immutable');
+	}
+
 	/**
 	 * @return IMessage
 	 */
