@@ -55,7 +55,7 @@ if ($_['debug']) {
 		<div id="app-settings">
 			<div id="app-settings-header">
 				<button class="settings-button"
-						data-apps-slide-toggle="#app-settings-content"></button>
+						data-apps-slide-toggle="#app-settings-content"><?php p($l->t('Settings'));?></button>
 			</div>
 			<div id="app-settings-content"></div>
 		</div>
